==> typo3-src_3.7.0.orig.tar.gz: typo3_src-3.7.0/typo3/index_re.php <==
<?php
/***************************************************************
*  Copyright notice
*
*  (c) 1999-2004 Kasper Skaarhoj (kasperYYYY@typo3.com)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*  A copy is found in the textfile GPL.txt and important notices to the license
*  from the author is found in LICENSE.txt distributed with these scripts.
*
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/
/**
 * Apache-trailing-slash workaround
 *
 * Meant to solve the trailing slash problem with Apache:
 *
 * Make a mod_rewrite rule like this:
 * 		RewriteRule   ^typo3$  typo3/index_re.php
 * ... and this document will redirect to the right script.
 *
 * $Id: index_re.php,v 1.6 2004/09/13 22:57:22 typo3 Exp $
 *
 * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
 * @package TYPO3
 * @subpackage core
 */

define('TYPO3_PROCEED_IF_NO_USER', 1);
require ('init.php');
header('Location: '.t3lib_div::locationHeaderUrl(t3lib_div::getIndpEnv('TYPO3_REQUEST_DIR').'index.php'));
?>

==> typo3-src_4.3.9+dfsg1.orig.tar.gz: typo3_src-4.3.9/typo3/index_re.php <==
<?php
/***************************************************************
*  Copyright notice
*
*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*  A copy is found in the textfile GPL.txt and important notices to the license
*  from the author is found in LICENSE.txt distributed with these scripts.
*
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/
/**
 * Apache-trailing-slash workaround
 *
 * Meant to solve the trailing slash problem with Apache:
 *
 * Make a mod_rewrite rule like this:
 * 		RewriteRule   ^typo3$  typo3/index_re.php
 * ... and this document will redirect to the right script.
 *
 * $Id: index_re.php 6469 2009-11-17 23:56:35Z benni $
 *
 * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
 * @package TYPO3
 * @subpackage core
 */

define('TYPO3_PROCEED_IF_NO_USER', 1);
require ('init.php');
t3lib_utility_Http::redirect(t3lib_div::getIndpEnv('TYPO3_REQUEST_DIR') . 'index.php');
?>
